import React, { useState } from 'react';
import { BrowserRouter, Route, Routes } from 'react-router-dom';

import PrivateRoute from './components/PrivateRoute';
import Loading from './components/Loading';
import NavBar from './components/NavBar';
import LandingPage from './views/LandingPage';
import Chart from './views/ChartPage';
import Profile from './views/Profile';
import { useAuth0 } from './react-auth0-spa';
// import history from './utils/history';
import clsx from 'clsx';
import { makeStyles } from '@material-ui/core/styles';
import CssBaseline from '@material-ui/core/CssBaseline';
import Drawer from '@material-ui/core/Drawer';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import Container from '@material-ui/core/Container';
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import Navigation from './components/Navigation';
import HomePage from './views/HomePage';
import DetailPage from './views/DetailPage';

const drawerWidth = 240;

const useStyles = makeStyles((theme) => ({
  root: {
    display: 'flex',
  },
  toolbarIcon: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-end',
    padding: '0 8px',
    ...theme.mixins.toolbar,
  },
  title: {
    flexGrow: 1,
  },
  drawerPaper: {
    position: 'relative',
    whiteSpace: 'nowrap',
    width: drawerWidth,
    transition: theme.transitions.create('width', {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.enteringScreen,
    }),
  },
  drawerPaperClose: {
    overflowX: 'hidden',
    width: theme.spacing(7),
    [theme.breakpoints.up('sm')]: {
      width: theme.spacing(9),
    },
  },
  appBarSpacer: theme.mixins.toolbar,
  content: {
    flexGrow: 1,
    height: '100vh',
    overflow: 'auto',
  },
  container: {
    paddingTop: theme.spacing(4),
    paddingBottom: theme.spacing(4),
  },
  paper: {
    padding: theme.spacing(2),
    display: 'flex',
    overflow: 'auto',
    flexDirection: 'column',
  },
  fixedHeight: {
    height: 240,
  },
}));

const App = () => {
  const { loading, isAuthenticated } = useAuth0();
  const classes = useStyles();
  const [open, setOpen] = useState(true);

  if (loading) {
    return <Loading />;
  }

  const handleDrawerOpen = () => {
    setOpen(true);
  };
  const handleDrawerClose = () => {
    setOpen(false);
  };

  return (
    <div className={classes.root}>
      <BrowserRouter>
        <CssBaseline />
        <NavBar open={open} handleOpen={handleDrawerOpen} />
        {isAuthenticated && (
          <Drawer
            variant="permanent"
            classes={{
              paper: clsx(classes.drawerPaper, !open && classes.drawerPaperClose),
            }}
            open={open}
          >
            <div className={classes.toolbarIcon}>
              <IconButton onClick={handleDrawerClose}>
                <ChevronLeftIcon />
              </IconButton>
            </div>
            <Divider />
            <Navigation />
            <Divider />
          </Drawer>
        )}
        <main className={classes.content}>
          <div className={classes.appBarSpacer} />
          <Container maxWidth="lg" className={classes.container} style={{ height: '100%' }}>
            <Routes>
              <Route path="/home-page" element={<PrivateRoute component={HomePage} />} />
              <Route path="/profile" element={<PrivateRoute component={Profile} />} />
              <Route path="/chart" element={<PrivateRoute component={Chart} />} />
              <Route path="/detail/:id" element={<DetailPage />} />
              <Route index path="/" element={<LandingPage />} />
            </Routes>
          </Container>
        </main>
      </BrowserRouter>
    </div>
  );
};

export default App;
